Utility Functions — HandyPy 0.2 documentation

# Utility Functions

`handypy.utils.` `load_yaml_namespace`(filename: str) → argparse.Namespace

  Load YAML config into a Namespace object

  Parameters

    filename – YAML file

  Returns

    Namespace object that attributes are accessible directly

`handypy.utils.` `set_log`(level: str = 'info') → None

  Set Logger level

  Parameters

    level – info|warn|error|critical etc.

`handypy.utils.` `validate_folder`(folder: str) → None

  Validate target folder exists, if not exist, an empty folder will be created.

  Parameters

    folder – folder path